@@ -75,20 +75,16 @@ CookieManager::CookieManager(QWidget *parent)
     ui->blackList->addItems(settings.value("blacklist", QStringList()).toStringList());
     settings.endGroup();
 
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 11, 0)
-    ui->filter3rdParty->hide();
-#endif
-
     ui->search->setPlaceholderText(tr("Search"));
     ui->cookieTree->setDefaultItemShowMode(TreeWidget::ItemsCollapsed);
     ui->cookieTree->sortItems(0, Qt::AscendingOrder);
     ui->cookieTree->header()->setDefaultSectionSize(220);
     ui->cookieTree->setFocus();
 
-    ui->whiteList->setSortingEnabled(true);
-    ui->blackList->setSortingEnabled(true);
+    ui->whiteList->sortItems(Qt::AscendingOrder);
+    ui->blackList->sortItems(Qt::AscendingOrder);
 
-    QShortcut* removeShortcut = new QShortcut(QKeySequence("Del"), this);
+    auto* removeShortcut = new QShortcut(QKeySequence("Del"), this);
     connect(removeShortcut, &QShortcut::activated, this, &CookieManager::deletePressed);
 
     connect(ui->search, &QLineEdit::textChanged, this, &CookieManager::filterString);
@@ -96,8 +92,10 @@ CookieManager::CookieManager(QWidget *parent)
     connect(mApp->cookieJar(), &CookieJar::cookieRemoved, this, &CookieManager::removeCookie);
 
     // Load cookies
-    foreach (const QNetworkCookie &cookie, mApp->cookieJar()->getAllCookies())
+    const auto allCookies = mApp->cookieJar()->getAllCookies();
+    for (const QNetworkCookie &cookie : allCookies) {
         addCookie(cookie);
+    }
 
     QzTools::setWmClass("Cookies", this);
 }
@@ -119,25 +117,25 @@ void CookieManager::removeAll()
 
 void CookieManager::remove()
 {
-    QTreeWidgetItem* current = ui->cookieTree->currentItem();
-    if (!current) {
-        return;
-    }
-
     QList<QNetworkCookie> cookies;
+    auto selection = ui->cookieTree->selectedItems();
 
-    if (current->childCount()) {
-        for (int i = 0; i < current->childCount(); ++i) {
-            QTreeWidgetItem *item = current->child(i);
-            if (item && m_itemHash.contains(item)) {
-                cookies.append(m_itemHash.value(item));
+    for (int i = 0; i < selection.count(); i++) {
+        QTreeWidgetItem* current = selection[i];
+
+        if (current->childCount()) {
+            for (int i = 0; i < current->childCount(); ++i) {
+                QTreeWidgetItem *item = current->child(i);
+                if (item && m_itemHash.contains(item)) {
+                    cookies.append(m_itemHash.value(item));
+                }
             }
+        } else if (m_itemHash.contains(current)) {
+            cookies.append(m_itemHash.value(current));
         }
-    } else if (m_itemHash.contains(current)) {
-        cookies.append(m_itemHash.value(current));
     }
 
-    foreach (const QNetworkCookie &cookie, cookies) {
+    for (const QNetworkCookie &cookie : qAsConst(cookies)) {
         mApp->cookieJar()->deleteCookie(cookie);
     }
 }
@@ -157,6 +155,16 @@ void CookieManager::currentItemChanged(QTreeWidgetItem* current, QTreeWidgetItem
         ui->secure->setText(tr("<cookie not selected>"));
         ui->expiration->setText(tr("<cookie not selected>"));
 
+        ui->removeOne->setText(tr("Remove cookies"));
+        return;
+    } else if (ui->cookieTree->selectedItems().count() > 1) {
+        ui->name->setText(tr("<multiple cookies selected>"));
+        ui->value->setText(tr("<multiple cookies selected>"));
+        ui->server->setText(tr("<multiple cookies selected>"));
+        ui->path->setText(tr("<multiple cookies selected>"));
+        ui->secure->setText(tr("<multiple cookies selected>"));
+        ui->expiration->setText(tr("<multiple cookies selected>"));
+
         ui->removeOne->setText(tr("Remove cookies"));
         return;
     }
@@ -222,7 +230,7 @@ QString CookieManager::cookieDomain(const QNetworkCookie &cookie) const
 {
     QString domain = cookie.domain();
     if (domain.startsWith(QLatin1Char('.'))) {
-        domain = domain.mid(1);
+        domain.remove(0, 1);
     }
     return domain;
 }
@@ -235,7 +243,7 @@ QTreeWidgetItem *CookieManager::cookieItem(const QNetworkCookie &cookie) const
         if (it.value() == cookie)
             return it.key();
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void CookieManager::removeBlacklist()
@@ -283,7 +291,7 @@ void CookieManager::addCookie(const QNetworkCookie &cookie)
         item = new QTreeWidgetItem(findParent);
     }
     else {
-        QTreeWidgetItem* newParent = new QTreeWidgetItem(ui->cookieTree);
+        auto* newParent = new QTreeWidgetItem(ui->cookieTree);
         newParent->setText(0, domain);
         newParent->setIcon(0, IconProvider::standardIcon(QStyle::SP_DirIcon));
         newParent->setData(0, Qt::UserRole + 10, cookie.domain());
@@ -312,7 +320,7 @@ void CookieManager::removeCookie(const QNetworkCookie &cookie)
     if (item->parent() && item->parent()->childCount() == 1) {
         m_domainHash.remove(cookieDomain(cookie));
         delete item->parent();
-        item = Q_NULLPTR;
+        item = nullptr;
     }
 
     delete item;
